@@ -1,7 +1,7 @@
 from lumiere.backend.explain.pdp import get_partial_dependence_values
-from lumiere.backend.explain.shapley import get_shap_values
+from lumiere.backend.explain.shapley import get_shap_features_importance
 
 __all__ = [
-    "get_shap_values",
     "get_partial_dependence_values",
+    "get_shap_features_importance",
 ]
